@@ -17,7 +17,7 @@ our @ISA = qw(Math::BigInt);
 our @EXPORT_OK = qw/objectify/;
 my $class = 'Math::BigInt::Lite';
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 ##############################################################################
 # global constants, flags and accessory
@@ -612,7 +612,7 @@ sub from_hex {
                      ^
                      \s*
                      ( [+-]? )
-                     ( 0 [Xx] )?
+                     ( 0? [Xx] )?
                      (
                          [0-9a-fA-F]*
                          ( _ [0-9a-fA-F]+ )*
@@ -659,7 +659,7 @@ sub from_oct {
                      ^
                      \s*
                      ( [+-]? )
-                     ( 0 [Oo] )?
+                     ( 0? [Oo] )?
                      (
                          [0-7]*
                          ( _ [0-7]+ )*
@@ -706,7 +706,7 @@ sub from_bin {
                      ^
                      \s*
                      ( [+-]? )
-                     ( 0 [Bb] )?
+                     ( 0? [Bb] )?
                      (
                          [01]*
                          ( _ [01]+ )*
